function DocumentViewer(url) {
    this._constructor(url);
}
(function() { // create local scope;

    DocumentViewer.Messages = {Loading: 'Loading...'};

    var IFRAME_ID = "DocumentViewerWindow";
    var BLANK_URL = "about:blank";

    DocumentViewer.prototype = {

        url: null,
        dialog: null,
        viewerHolder: null,

        _constructor: function(url) {
            this.url = url;
        },

        init: function() {
            if (this.dialog == null) {
                this.dialog = new DocumentViewerDialog(this);
                this.viewerHolder = this._createViewerHolder();
                Utils.setStyle(this.viewerHolder, {display: "none"});
                this.dialog.setContent(this.viewerHolder);
            }
        },

        load: function(filename) {
            this.init();

            this.viewerHolder.src = this._createUrl(filename);

            this.dialog.setButtonVisible(ModalDialog.BUTTON_OK, false);
            this.dialog.setButtonVisible(ModalDialog.BUTTON_CANCEL, true);
            this.dialog.setMessage(DocumentViewer.Messages.Loading);
            this.dialog.pack();
            this.dialog.setVisible(true);
        },

        onLoadFinish: function(filename) {
            this.dialog.setMessage(null);
            this.dialog.hideButtonsBar();
            this.dialog.setTitle(filename);
            Utils.setStyle(this.viewerHolder, {height: "100%", display: "block"});

            var viewport = document.viewport.getDimensions();
            this.dialog.setSize(viewport.width * 0.8, viewport.height * 0.85);
            this.dialog.setVisible(true);
        },

        onLoadCancel: function() {
            Utils.setStyle(this.viewerHolder, {display: "none"});
            this.viewerHolder.src = BLANK_URL;
            this.dialog.setMessage(null);
            this.dialog.setVisible(false);
        },

        onError: function(message) {
            Utils.setStyle(this.viewerHolder, {display: "none"});
            this.dialog.setMessage(message);
            this.dialog.setButtonVisible(ModalDialog.BUTTON_OK, true);
            this.dialog.setButtonVisible(ModalDialog.BUTTON_CANCEL, false);

            this.dialog.pack();
            this.dialog.setVisible(true);
        },

        _createUrl: function(filename) {
            return encodeURI(this.url + filename);
        },

        _createViewerHolder: function() {
            var result = document.getElementById(IFRAME_ID);

            if (result == null) {
                var holder = document.body.appendChild(document.createElement("div"));
                holder.innerHTML = "<iframe src='" + BLANK_URL + "' id='" + IFRAME_ID + "' name='" + IFRAME_ID + "' "
                                   + "frameborder='0' " // border bug in IE7
                                   + "style='width:100%;height:0;border:none;'></iframe>";
                holder.style.position = "relative";
                holder.style.top = "0px";
                holder.style.left = "0px";

                result = holder.getElementsByTagName("iframe")[0];
            }

            return result;
        }

    };
})();