function DocumentViewerDialog(listener) {
    this._constructor(listener);
}(function() { // create local scope;

    DocumentViewerDialog.Buttons = {OK: 'OK', CANCEL: 'Cancel', CLOSE: 'Close'};

    var DAILOG_ID = "DocumentViewerDialog";
    var CLOSE_BUTTON_CSS_CLASS = "ln";

    DocumentViewerDialog.prototype = {

        dialog: null,
        messageHolder: null,
        listener: null,

        _constructor: function(listener) {
            this.dialog = new ModalDialog(DAILOG_ID, true);
            this.listener = listener;
            this._compose();
        },

        setTitle: function(title) {
            this.dialog.setTitle(title);
        },

        setContent: function(content) {
            this.dialog.getContent().appendChild(content);
        },

        setMessage: function(message) {
            if (message != null) {
                while (this.messageHolder.hasChildNodes()) {
                    this.messageHolder.removeChild(this.messageHolder.lastChild);
                }
                this.messageHolder.appendChild(document.createTextNode(message));
                Utils.setStyle(this.messageHolder, {display: "block"});
            } else {
                Utils.setStyle(this.messageHolder, {display: "none"});
            }
        },

        setSize: function(width, height) {
            this.dialog.setSize(width, height);
        },

        isVisible: function() {
            return this.dialog.isVisible();
        },

        setVisible: function(visible) {
            this.dialog.setVisible(visible);
            this._registerKeyHandlers();
        },

        pack: function() {
            this.dialog.pack();
        },

        getButton: function(type) {
            return this.dialog.getButton(type);
        },

        setButtonVisible: function(type, visible) {
            var button = this.dialog.getButton(type);

            if (button != null) {
                Utils.setVisible(button, visible);
                this.dialog.setButtonEnabled(type, visible);
                if (visible) {
                    Utils.setVisible(this.dialog.buttonsBar, true);
                }
            }
        },

        hideButtonsBar: function() {
            Utils.setVisible(this.dialog.buttonsBar, false);
        },

        onSubmit: function() {
            this.dialog.setVisible(false);
        },

        onCancel: function() {
            this.listener.onLoadCancel();
        },

        processKeyEvent: function(ke) {
            var code = ke.getKeyCode();

            switch (code) {
                case KeyEvent.VK_ESCAPE:
                    ke.cancel();
                    this.onCancel();
                    break;
            }
        },

        _compose: function() {
            this.messageHolder = this.dialog.getContent().appendChild(document.createElement(Tag.DIV));
            Utils.setStyle(this.messageHolder, {display: "none"});

            var closeButton = document.createElement(Tag.SPAN);
            Utils.addCssClass(closeButton, CLOSE_BUTTON_CSS_CLASS);
            Utils.setStyle(closeButton, "float: right");
            closeButton.appendChild(document.createTextNode(DocumentViewerDialog.Buttons.CLOSE));

            var thisObj = this;
            closeButton.onclick = function() { thisObj.onCancel(); };
            this.dialog.titlePane.insertBefore(closeButton, this.dialog.titlePane.firstChild);
            this.dialog.addButton(ModalDialog.BUTTON_OK, DocumentViewerDialog.Buttons.OK, function() { thisObj.onSubmit(); });
            this.dialog.addButton(ModalDialog.BUTTON_CANCEL, DocumentViewerDialog.Buttons.CANCEL, function() { thisObj.onCancel(); });
        },

        _registerKeyHandlers: function() {
            var km = KeyboardManager.getInstance();
            if (this.isVisible()) {
                km.registerHandler(KeyEvent.VK_ESCAPE, this);
            } else {
                km.unregisterHandler(KeyEvent.VK_ESCAPE, this);
            }
        }

    };
})();