function EmailFileDialog(listener) {
    this._constructor(listener);
}
(function() { // create local scope;

    EmailFileDialog.Buttons = {OK: 'Send', CANCEL: 'Cancel'};
    EmailFileDialog.Messages = {TITLE: "Email File(s)", SUCCESS: "File(s) emailed successfully."};

    var MIN_SIZE = {width: 550, height: 400};

    EmailFileDialog.prototype = {

        listener: null,
        dialog: null,

        _constructor: function(listener) {
            this.listener = listener;
            this.dialog = new ModalDialog("EmailFileDialog");

            this.dialog.setTitle(EmailFileDialog.Messages.TITLE);
            this.dialog.addButton(ModalDialog.BUTTON_OK, EmailFileDialog.Buttons.OK, this.onSubmit.bind(this));
            this.dialog.addButton(ModalDialog.BUTTON_CANCEL, EmailFileDialog.Buttons.CANCEL, this.onCancel.bind(this));
        },

        setContent: function(content) {
            this.dialog.setContent(content);
        },

        setButtonEnabled: function(name, enable) {
            this.dialog.setButtonEnabled(name, enable);
        },

        setVisible: function(visible) {
            this.dialog.setVisible(visible);
            this._registerKeyHandlers();
        },

        isVisible: function() {
            return this.dialog.isVisible();
        },

        setSize: function(width, height) {
            this.dialog.setSize(Math.max(MIN_SIZE.width, width), Math.max(MIN_SIZE.height, height));
        },

        pack: function() {
            this.dialog.pack();
        },

        onSubmit: function() {
            this.listener.onSubmit();
        },

        onCancel: function() {
            this.listener.onCancel();
        },

        processKeyEvent: function(ke) {
            var code = ke.getKeyCode();

            switch (code) {
                case KeyEvent.VK_ENTER:
                    ke.cancel();
                    this.onSubmit();
                    break;

                case KeyEvent.VK_ESCAPE:
                    ke.cancel();
                    this.onCancel();
                    break;
            }
        },

        _registerKeyHandlers: function() {
            var km = KeyboardManager.getInstance();
            if (this.isVisible()) {
                km.registerHandler(KeyEvent.VK_ENTER, this);
                km.registerHandler(KeyEvent.VK_ESCAPE, this);
            } else {
                km.unregisterHandler(KeyEvent.VK_ENTER, this);
                km.unregisterHandler(KeyEvent.VK_ESCAPE, this);
            }
        }

    };
})();