function IFrameChannel(id) {
    this._constructor(id);
}
(function() {

    IFrameChannel.Method = {GET: "get", POST: "post"};

    var DEFAULT_ID = "IIFameChannel";
    var CHANNEL_HOLDER_ID = "IFrameChannelHolder";
    var BLANK_URL = "about:blank";

    IFrameChannel.prototype = {

        id: null,
        name: null,
        url: null,
        method: null,
        preventCaching: null,
        iframe: null,
        listeners: null,

        _constructor: function(id) {
            this.id = id || DEFAULT_ID;
            this.name = this.id;
            this.url = BLANK_URL;
            this.preventCaching = false;
            this.listeners = new Array();
        },

        setName: function(name) {
            this.name = name;
        },

        setPreventCaching: function(value) {
            this.preventCaching = !!value;
        },

        addLoadListener: function(listener) {
            Event.observe(this.iframe, "load", listener);
            this.listeners.push(listener);
        },

        removeLoadListener: function(listener) {
            Event.unobserve(this.iframe, "load", listener);

            var index = this.listeners.indexOf(listener);
            if (index != -1) {
                this.listeners.splice(index, 1);
            }
        },

        submit: function(form) {
            if (form == null) {
                return;
            }

            if (this.iframe == null) {
                this.iframe = this._create();
            }

            form.target = this.iframe.name;

            // crash in Safari without delay
            if (Utils.isSafariNavigator()) {
                (function(f) { f.submit(); return false; }.delay(50, form));
            } else {
                form.submit();
            }
            return false;
        },

        open: function(url, method) {
            this.url = url;
            this.method = method || IFrameChannel.Method.GET;
            this.iframe = this._create();
        },

        send: function(data) {
            if (this.method == IFrameChannel.Method.POST) {
                var form = this._createForm(data);
                this.submit(form);
                form.parentNode.removeChild(form);
            } else {
                this.iframe.src = this._createUrl(data);
            }
        },

        close: function() {
            if (this.iframe == null) {
                return;
            }

            while (this.listeners.length > 0) {
                this.removeLoadListener(this.listeners[0]);
            }

            this.iframe.src = BLANK_URL;
            var parent = this.iframe.parentNode;
            parent.removeChild(this.iframe);

            if (parent.id == CHANNEL_HOLDER_ID) {
                parent.parentNode.removeChild(parent);
            }

            this.iframe = null;
        },

        asElement: function() {
            return this.iframe;
        },

        asDocument: function() {
            var d = this.iframe.contentWindow || this.iframe.contentDocument;
            return d.document ? d.document : d;
        },

        _createForm: function(data) {
            var form = document.body.appendChild(document.createElement(Tag.FORM));
            form.setAttribute("action", this._createUrl({}));
            form.setAttribute("method", this.method);
            form.setAttribute("accept-charset", "utf-8");

            var inputs = this._toFormInputs(data);
            for (var i = 0; i < inputs.length; ++i) {
                form.appendChild(inputs[i]);
            }

            return form;
        },

        _createUrl: function(data) {
            if (this.preventCaching) {
                data["nocache"] = new Date().getTime();
            }

            var queryString = this._toQueryString(data);
            var uri = encodeURI(this.url);
            if (queryString.length > 0) {
                uri += (uri.indexOf("?") == -1 ? "?" : "&") + queryString;
            }

            return uri;
        },

        _convertToChannelData: function(data, provider) {
            var result = [];
            for (var key in data) {
                if (!data.hasOwnProperty(key)) {
                    continue;
                }
                var value = data[key];
                if (this._isArray(value)) {
                    for (var i = 0; i < value.length; ++i) {
                        result.push(provider(key, value[i]));
                    }
                } else {
                    result.push(provider(key, value));
                }
            }
            return result;
        },

        _toFormInputs: function(data) {
            return this._convertToChannelData(data, function(key, value) {
                var input = Utils.createInput(Tag.INPUT_TYPE_HIDDEN, key);
                input.value = value;
                return input;
            });
        },

        _toQueryString: function(data) {
            return this._convertToChannelData(data, function(key, value) {
                return key + "=" + encodeURIComponent(value);
            }).join("&");
        },

        _isArray: function(obj) {
            return obj != null && typeof obj == "object" && 'splice' in obj && 'join' in obj;
        },

        _create: function() {
            var result = $(this.id);

            if (result == null) {
                var holder = document.body.appendChild(document.createElement(Tag.DIV));
                holder.id = CHANNEL_HOLDER_ID;
                holder.innerHTML = "<iframe src='" + BLANK_URL + "' "
                                   + "id='" + this.id + "' name='" + this.name + "' "
                                   + "frameborder='0' " // border bug in IE7
                                   + "style='width:0;height:0;border:none;'></iframe>";
                result = holder.getElementsByTagName("iframe")[0];
                Utils.setStyle(result, {position: "relative", top: 0, left: 0});
            }

            return result;
        }
    };
})();