function DeleteUserDialog() {
    this._constructor();
}
(function() { // create local scope;

    DeleteUserDialog.Buttons = {OK: 'OK', CANCEL: 'Cancel'};
    DeleteUserDialog.Messages = {DELETE_CONFIRM: "Delete selected user(s)?"};
    DeleteUserDialog.Labels = {OWNED_ACCOUNTS: "Delete owned accounts"};

    var DIALOG_ID = "DeleteUserDialog";
    var OWNED_ACCOUNTS_NAME = "DeleteOwnedAccounts";

    DeleteUserDialog.prototype = {

        dialog: null,
        ownedAccountsBox: null,

        toString: function() { return DIALOG_ID; },

        _constructor: function() {
            this.dialog = new ModalDialog(DIALOG_ID);
            this.ownedAccountsBox = Utils.createInput(Tag.INPUT_TYPE_CHECKBOX, OWNED_ACCOUNTS_NAME);
            this.ownedAccountsBox.id = OWNED_ACCOUNTS_NAME;

            this._compose();
        },

        isVisible: function() {
            return this.dialog.isVisible();
        },

        setVisible: function(visible) {
            this.dialog.setVisible(visible);

            if (visible) {
                this._registerKeyHandlers();
            } else {
                this._unregisterKeyHandlers();
            }
        },

        isDeleteOwnedAccounts: function() {
            return $F(this.ownedAccountsBox) != null;
        },

        onSubmit: function() {
            this.setVisible(false);
        },

        onCancel: function() {
            this.ownedAccountsBox.checked = false;
            this.setVisible(false);
        },

        processKeyEvent: function(ke) {
            var code = ke.getKeyCode();

            switch (code) {
                case KeyEvent.VK_ENTER:
                    ke.cancel();
                    this.onSubmit();
                    break;

                case KeyEvent.VK_ESCAPE:
                    ke.cancel();
                    this.onCancel();
                    break;
            }
        },

        _compose: function() {
            var content = this.dialog.getContent();

            var messagePanel = document.createElement(Tag.PARAGRAPH);
            Utils.setStyle(messagePanel, "font-weight:bold;");
            messagePanel.appendChild(document.createTextNode(DeleteUserDialog.Messages.DELETE_CONFIRM));
            content.appendChild(messagePanel);

            var optionsPanel = document.createElement(Tag.DIV);
            Utils.setStyle(optionsPanel, "font-size:0.9em");
            optionsPanel.appendChild(this.ownedAccountsBox);
            Utils.setStyle(this.ownedAccountsBox, "margin-right:0.5em;vertical-align:sub");
            optionsPanel.appendChild(Utils.createLabel(DeleteUserDialog.Labels.OWNED_ACCOUNTS, this.ownedAccountsBox.id));
            optionsPanel.appendChild(document.createElement("BR"));
            content.appendChild(optionsPanel);

            var thisObj = this;
            this.dialog.addButton(ModalDialog.BUTTON_OK, DeleteUserDialog.Buttons.OK, function() {
                thisObj.onSubmit();
            });
            this.dialog.addButton(ModalDialog.BUTTON_CANCEL, DeleteUserDialog.Buttons.CANCEL, function() {
                thisObj.onCancel();
            });
        },

        _registerKeyHandlers: function() {
            var km = KeyboardManager.getInstance();
            km.registerHandler(KeyEvent.VK_ENTER, this);
            km.registerHandler(KeyEvent.VK_ESCAPE, this);
        },

        _unregisterKeyHandlers: function() {
            var km = KeyboardManager.getInstance();
            km.unregisterHandler(KeyEvent.VK_ENTER, this);
            km.unregisterHandler(KeyEvent.VK_ESCAPE, this);
        }
    };
})();